@@ -125,6 +125,8 @@ const char* Id_str(int tag) {
     return "Id.Lit_ArrayLhsClose";
   case Id::Lit_Splice:
     return "Id.Lit_Splice";
+  case Id::Lit_AtLBraceDot:
+    return "Id.Lit_AtLBraceDot";
   case Id::Lit_Other:
     return "Id.Lit_Other";
   case Id::Lit_EscapedChar:
@@ -159,6 +161,8 @@ const char* Id_str(int tag) {
     return "Id.Lit_Pound";
   case Id::Lit_TPound:
     return "Id.Lit_TPound";
+  case Id::Lit_TDot:
+    return "Id.Lit_TDot";
   case Id::Lit_Slash:
     return "Id.Lit_Slash";
   case Id::Lit_Percent:
@@ -255,6 +259,10 @@ const char* Id_str(int tag) {
     return "Id.Expr_RDArrow";
   case Id::Expr_DSlash:
     return "Id.Expr_DSlash";
+  case Id::Expr_TEqual:
+    return "Id.Expr_TEqual";
+  case Id::Expr_NotDEqual:
+    return "Id.Expr_NotDEqual";
   case Id::Expr_TildeDEqual:
     return "Id.Expr_TildeDEqual";
   case Id::Expr_At:
@@ -329,6 +337,8 @@ const char* Id_str(int tag) {
     return "Id.Char_Unicode8";
   case Id::Char_UBraced:
     return "Id.Char_UBraced";
+  case Id::Char_Pound:
+    return "Id.Char_Pound";
   case Id::Char_Literals:
     return "Id.Char_Literals";
   case Id::Re_Start:
@@ -399,8 +409,12 @@ const char* Id_str(int tag) {
     return "Id.Left_ProcSubOut";
   case Id::Left_AtParen:
     return "Id.Left_AtParen";
-  case Id::Left_AmpParen:
-    return "Id.Left_AmpParen";
+  case Id::Left_CaretParen:
+    return "Id.Left_CaretParen";
+  case Id::Left_CaretBracket:
+    return "Id.Left_CaretBracket";
+  case Id::Left_CaretBrace:
+    return "Id.Left_CaretBrace";
   case Id::Left_PercentParen:
     return "Id.Left_PercentParen";
   case Id::Right_DoubleQuote:
