@@ -8,7 +8,11 @@
 
 // Needed for the field below to be valid
 // https://stackoverflow.com/questions/14261534/temporarily-overwrite-a-macro-in-c-preprocessor
+// 
+// TODO: Replace with #prgram with something portable
+// I think we just need to rewrite e.errno -> e.errno_ in mycpp.
 
+#pragma push_macro("errno");
 #undef errno
 
 // Base class that mycpp generates.
@@ -17,6 +21,8 @@ class _OSError {
   int errno;
 };
 
+#pragma pop_macro("errno");
+
 class IOError : public _OSError {};
 
 class OSError : public _OSError {};
